@@ -25,7 +25,8 @@ class LayerScoreColourPicker(ColourPicker):
 
             else:
                 file_layer_score = self._scorer.layer_scores[file_path]
-                score_percentile = file_layer_score / max(self._scorer.layer_scores.values())
+                max_score = max(self._scorer.layer_scores.values())
+                score_percentile = 0 if max_score == 0 else (file_layer_score / max_score)
                 colour_index = round(score_percentile * (len(self._colour_scale)-1))
 
                 self._history[file_path] = self._colour_scale[colour_index]
